@@ -58,7 +58,7 @@
     </message>
     <message>
         <location filename="settingsdialog.ui" line="132"/>
-        <source>Filter</source>
+        <source>Show</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
