@@ -58,8 +58,8 @@
     </message>	
     <message>
         <location filename="settingsdialog.ui" line="132"/>
-        <source>Filter</source>
-        <translation type="unfinished">Фильтр</translation>
+        <source>Show</source>
+        <translation type="unfinished">Показать</translation>
     </message>
     <message>
         <location filename="settingsdialog.ui" line="149"/>
